==> bidmad_flutter_plugin-0.0.4-dev9.tar.gz: lib/FlutterBaseInterstitial.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/services.dart';

class FlutterBaseInterstitial {
  String _channelNm;
  MethodChannel _platform;

  var onLoadAdCallback = null;
  var onShowAdCallback = null;
  var onFailAdCallback = null;
  var onCloseAdCallback = null;

  FlutterBaseInterstitial({
    @required String channelName
  }){
    this._channelNm = channelName;
    _initChannel(_channelNm);
  }

  Future<void> _initChannel(String channelNm) async {
    _platform = MethodChannel(channelNm);
    _platform.setMethodCallHandler(_handleMethod);
    await _platform.invokeMethod('makeInterstitial');
  }

  Future<void> load() async {
    await _platform.invokeMethod('load');
  }

  Future<void> show() async {
    await _platform.invokeMethod('show');
  }

  Future<void> isLoaded() async {

  }

  Future<void> setAdInfo(String zoneId) async {
    await _platform.invokeMethod('setAdInfo', zoneId);
  }

  Future<void> setCallbackListener({
    void Function(String zoneId) onLoadAd,
    void Function(String zoneId) onShowAd,
    void Function(String zoneId) onFailAd,
    void Function(String zoneId) onCloseAd
  }) async {

    if(onLoadAd != null){
      onLoadAdCallback = onLoadAd;
    }
    if(onShowAd != null){
      onShowAdCallback = onShowAd;
    }
    if(onFailAd != null){
      onFailAdCallback = onFailAd;
    }
    if(onCloseAd != null){
      onCloseAdCallback = onCloseAd;
    }
  }

  Future<dynamic> _handleMethod(MethodCall call) async {
    String zoneId = call.arguments.toString();
    switch (call.method) {
      case 'onLoadAd':
        if (onLoadAdCallback != null) {
          onLoadAdCallback(zoneId);
        };
        break;
      case 'onShowAd':
        if (onShowAdCallback != null) {
          onShowAdCallback(zoneId);
        };
        break;
      case 'onFailAd':
        if (onFailAdCallback != null) {
          onFailAdCallback(zoneId);
        };
        break;
      case 'onCloseAd':
        if (onCloseAdCallback != null) {
          onCloseAdCallback(zoneId);
        };
        break;
      default:
        throw ('method not defined');
    }
  }
}

==> bidmad_flutter_plugin-0.7.1-dev1.tar.gz: lib/FlutterBaseInterstitial.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/services.dart';

class FlutterBaseInterstitial {
  String _channelNm;
  late MethodChannel _platform;

  var onLoadAdCallback = null;
  var onShowAdCallback = null;
  var onFailAdCallback = null;
  var onCloseAdCallback = null;

  FlutterBaseInterstitial({
    required String channelName
  }) : this._channelNm = channelName {
    _initChannel(_channelNm);
  }

  Future<void> _initChannel(String channelNm) async {
    _platform = MethodChannel(channelNm);
    _platform.setMethodCallHandler(_handleMethod);
    await _platform.invokeMethod('makeInterstitial');
  }

  Future<void> load() async {
    await _platform.invokeMethod('load');
  }

  Future<void> show() async {
    await _platform.invokeMethod('show');
  }

  Future<bool> isLoaded() async {
    return await _platform.invokeMethod('isLoaded');
  }

  Future<void> setAdInfo(String zoneId) async {
    await _platform.invokeMethod('setAdInfo', zoneId);
  }

  Future<void> setCallbackListener({
    void Function(String zoneId)? onLoadAd,
    void Function(String zoneId)? onShowAd,
    void Function(String zoneId)? onFailAd,
    void Function(String zoneId)? onCloseAd
  }) async {

    if(onLoadAd != null){
      onLoadAdCallback = onLoadAd;
    }
    if(onShowAd != null){
      onShowAdCallback = onShowAd;
    }
    if(onFailAd != null){
      onFailAdCallback = onFailAd;
    }
    if(onCloseAd != null){
      onCloseAdCallback = onCloseAd;
    }
  }

  Future<dynamic> _handleMethod(MethodCall call) async {
    String zoneId = call.arguments.toString();
    switch (call.method) {
      case 'onLoadAd':
        if (onLoadAdCallback != null) {
          onLoadAdCallback(zoneId);
        };
        break;
      case 'onShowAd':
        if (onShowAdCallback != null) {
          onShowAdCallback(zoneId);
        };
        break;
      case 'onFailAd':
        if (onFailAdCallback != null) {
          onFailAdCallback(zoneId);
        };
        break;
      case 'onCloseAd':
        if (onCloseAdCallback != null) {
          onCloseAdCallback(zoneId);
        };
        break;
      default:
        throw ('method not defined');
    }
  }
}
